@@ -36,6 +36,7 @@ import string
 import re
 import time
 import StringIO
+import codecs
 
 from string import find, rfind
 from decimal import Decimal
@@ -305,8 +306,9 @@ def canonical(str_in):
     - Converfting unicode IRI to utf-8
     - Escaping all non-ASCII
     - De-escaping, if escaped, ALPHA (%41-%5A and %61-%7A), DIGIT (%30-%39),
-      hyphen (%2D), period (%2E), underscore (%5F), or tilde (%7E) (Sect 2.4) 
+    hyphen (%2D), period (%2E), underscore (%5F), or tilde (%7E) (Sect 2.4) 
     - Making all escapes uppercase hexadecimal
+    
     Not done:
     - Making URI scheme lowercase
     - changing /./ or  /foo/../ to / with care not to change host part
@@ -738,13 +740,12 @@ def Canonicalize(node, output=None, **kw):
     Return the text; if output is specified then output.write will
     be called to output the text and None will be returned
     Keyword parameters:
-        nsdict: a dictionary of prefix:uri namespace entries
-                assumed to exist in the surrounding context
-        comments: keep comments if non-zero (default is 0)
-        subset: Canonical XML subsetting resulting from XPath
-                (default is [])
-        unsuppressedPrefixes: do exclusive C14N, and this specifies the
-                prefixes that should be inherited.
+    nsdict -- a dictionary of prefix:uri namespace entries
+    assumed to exist in the surrounding context
+    comments -- keep comments if non-zero (default is 0)
+    subset -- Canonical XML subsetting resulting from XPath (default is [])
+    unsuppressedPrefixes -- do exclusive C14N, and this specifies the
+    prefixes that should be inherited.
     '''
     if output:
         apply(_implementation, (node, output.write), kw)
@@ -909,6 +910,9 @@ class SinkParser:
 
         if not isinstance(octets, unicode):        
            str = octets.decode('utf-8')
+           # NB already decoded, so \ufeff
+           if len(str) > 0 and str[0] == codecs.BOM_UTF8.decode('utf-8'):
+               str = str[1:]
         else: 
            str=octets
 
@@ -2233,11 +2237,14 @@ class N3Parser(Parser):
     def __init__(self):
         pass
 
-    def parse(self, source, graph):
+    def parse(self, source, graph, encoding="utf-8"):
         # we're currently being handed a Graph, not a ConjunctiveGraph
         assert graph.store.context_aware # is this implied by formula_aware
         assert graph.store.formula_aware
 
+        if encoding not in [None, "utf-8"]:
+           raise Exception("N3 files are always utf-8 encoded, I was passed: %s"%encoding)
+
         conj_graph = ConjunctiveGraph(store=graph.store)
         conj_graph.default_context = graph # TODO: CG __init__ should have a default_context arg
         # TODO: update N3Processor so that it can use conj_graph as the sink
