@@ -20,13 +20,14 @@ import logging
 _LOGGER = logging.getLogger(__name__)
 
 import base64
+import re
 
 import threading
 from urlparse import urlparse, urljoin, urldefrag
 from string import ascii_letters, rsplit
 from random import choice
 from itertools import islice
-from datetime import date, time, datetime
+from datetime import date, time, datetime, timedelta
 from time import strptime
 
 try:
@@ -133,7 +134,7 @@ class URIRef(Identifier):
             return False
 
     def __str__(self):
-        return self.encode("unicode-escape")
+        return self.encode()
 
     def __repr__(self):
         if self.__class__ is URIRef:
@@ -237,7 +238,7 @@ class BNode(Identifier):
             return False
 
     def __str__(self):
-        return self.encode("unicode-escape")
+        return self.encode()
 
     def __repr__(self):
         if self.__class__ is BNode:
@@ -425,8 +426,8 @@ class Literal(Identifier):
         >>> Literal('1', datatype=XSD.double) in a
         False
 
-        [[
-        Called for the key object for dictionary operations, 
+        
+        "Called for the key object for dictionary operations, 
         and by the built-in function hash(). Should return 
         a 32-bit integer usable as a hash value for 
         dictionary operations. The only required property 
@@ -434,20 +435,19 @@ class Literal(Identifier):
         hash value; it is advised to somehow mix together 
         (e.g., using exclusive or) the hash values for the 
         components of the object that also play a part in 
-        comparison of objects. 
-        ]] -- 3.4.1 Basic customization (Python)
+        comparison of objects." -- 3.4.1 Basic customization (Python)
 
-        [[
-        Two literals are equal if and only if all of the following hold:
+        "Two literals are equal if and only if all of the following hold:
         * The strings of the two lexical forms compare equal, character by character.
         * Either both or neither have language tags.
         * The language tags, if any, compare equal.
         * Either both or neither have datatype URIs.
-        * The two datatype URIs, if any, compare equal, character by character.
-        ]] -- 6.5.1 Literal Equality (RDF: Concepts and Abstract Syntax)
+        * The two datatype URIs, if any, compare equal, character by character."
+        -- 6.5.1 Literal Equality (RDF: Concepts and Abstract Syntax)
 
         """
-        return hash(str(self)) ^ hash(self.language) ^ hash(self.datatype)
+        
+        return Identifier.__hash__(self) ^ hash(self.language) ^ hash(self.datatype)
 
     def __eq__(self, other):
         """
@@ -624,7 +624,7 @@ class Literal(Identifier):
                             ).replace('"', '\\"')
 
     def __str__(self):
-        return self.encode("unicode-escape")
+        return self.encode()
 
     def __repr__(self):
         args = [super(Literal, self).__repr__()]
@@ -738,9 +738,29 @@ def _strToDateTime(v) :
             except:
                 try:
                     # %f only works in python 2.6
+                    # in 2.5 a ValueError will be raised, and we still return 
+                    # just the string
                     return datetime.strptime(v, "%Y-%m-%dT%H:%M:%S.%f")
                 except:
-                    return v
+                    try:
+                        # %f only works in python 2.6
+                        return datetime.strptime(v, "%Y-%m-%dT%H:%M:%S.%fZ")
+                    except:
+                        try:
+                            # %f only works in python 2.6
+                            # HACK split off the timezone offset
+                            #  works for "2011-01-16T19:39:18.239743+01:00"
+                            m = re.match(r'(.*)([-+])(\d{2}):(\d{2})$',
+                                         v).groups()
+                            d = datetime.strptime(m[0], "%Y-%m-%dT%H:%M:%S.%f")
+                            t = timedelta(hours=int(m[2]), seconds=int(m[3]))
+                            if m[1] == '+':
+                                d += t
+                            else:
+                                d -= t
+                            return d
+                        except:
+                            return v
 
     return datetime(tstr.tm_year, tstr.tm_mon, tstr.tm_mday,
                     tstr.tm_hour, tstr.tm_min, tstr.tm_sec)
